@@ -36,12 +36,16 @@ def QuickML_Ensembling(X_train, y_train, X_test, y_test='', modeltype='Regressio
     """
     start_time = time.time()
     seed = 99
+    FOLDS = 5
     if len(X_train) <= 100000 or X_train.shape[1] < 50:
         NUMS = 100
-        FOLDS = 5
     else:
+        try:
+            X_train = X_train.sample(frac=0.30,random_state=99)
+            y_train = y_train[X_train.index]
+        except:
+            pass
         NUMS = 200
-        FOLDS = 10
     ## create Voting models
     estimators = []
     if modeltype == 'Regression':
@@ -120,7 +124,8 @@ def QuickML_Ensembling(X_train, y_train, X_test, y_test='', modeltype='Regressio
                 metrics1 = 0
             estimators.append(('Bagging',model5, metrics1))
         else:
-            model5 = LogisticRegressionCV(Cs=np.linspace(0.01,100,20),cv=scv,scoring=scoring,
+            model5 = LogisticRegressionCV(Cs=np.linspace(0.01,100,20),solver='liblinear',
+                                          cv=scv,scoring=scoring,
                                           random_state=seed)
             results1 = model5.fit(X_train,y_train).predict(X_test)
             if not isinstance(y_test, str):
